==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Abbrechen',
	'bouton_enlever' => 'Entfernen',

	// C
	'cfg_charger_public' => 'Skripte im öffentlichen Bereich',
	'cfg_charger_public_case' => 'Skripte im öffentlichen Bereich laden',
	'cfg_client_height' => 'Höhe',
	'cfg_client_height_explication' => 'Maximale Höhe des Bildes (px)',
	'cfg_client_quality' => 'Qualität',
	'cfg_client_quality_explication' => 'Komprimierung des Bildes nach dem Zuschneiden, Wert zwischen 0 und 100, Standard: 85',
	'cfg_client_width' => 'Breite',
	'cfg_client_width_explication' => 'Maximale Breite des Bildes (px)',
	'cfg_explication_parametrages' => 'Diese Optionen beziehen sich nur auf Dateifelder, die mit einem Drag-and-Drop-Block verwaltet werden.',
	'cfg_explication_retailler_image' => 'Wenn Breite und/oder Höhe angegeben sind, werden die Bilder vom Browser vor dem Senden an den Server in der Größe angepasst.',
	'cfg_max_file_size' => 'Maximale Dateigröße',
	'cfg_max_file_size_explication' => 'Maximale Dateigröße (in Mio).',
	'cfg_titre_parametrages' => 'Datei-Upload',
	'cfg_titre_retailler_image' => 'Aktivieren Sie die Änderung der Bildgröße durch den Browser',
	'cfg_titre_retailler_image_actif' => 'Die Ändern der Bildgröße durch den Browser ist mit den folgenden Werten aktiviert',
	'choisir' => 'Auswählen',

	// D
	'deposer_la_vignette_ici' => 'Miniaturbild  hier ablegen',
	'deposer_le_logo_ici' => 'LOGO hier ablegen',
	'deposer_vos_fichiers_ici' => 'Dateien  hier ablegen',
	'deposer_votre_fichier_ici' => 'Datei hier ablegen',

	// E
	'erreur_de_transfert' => 'Übertragungsfehler',
	'erreur_probleme_survenu' => 'Ein Problem ist aufgetreten...',
	'erreur_taille_max' => 'Die Datei darf nicht größer sein als @taille@',
	'erreur_type_fichier' => 'Falscher Dateityp!',

	// F
	'fichier_efface' => 'Datei gelöscht',

	// O
	'ou' => 'oder',

	// S
	'selectionner' => 'Auswählen',
	'succes_fichier_envoye' => 'Die Datei wurde gesendet',
	'succes_logo_envoye' => 'Das Logo wurde gesendet',
	'succes_vignette_envoyee' => 'Das Miniaturbild wurde gesendet',

	// T
	'televerser' => 'Hochladen',
	'titre_page_configurer_bigup' => 'Big Upload konfigurieren',

	// Z
	'zbug_necessite_plugin' => 'Der Tag <code>@balise@</code> benötigt das Plugin <code>@plugin@</code>'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/bigup/lang/bigup_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-bigup?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// B
	'bigup_titre' => 'Big Upload',
	'bouton_annuler' => 'Abbrechen',
	'bouton_enlever' => 'Entfernen',

	// C
	'cfg_charger_public' => 'Skripte im öffentlichen Bereich',
	'cfg_charger_public_case' => 'Skripte im öffentlichen Bereich laden',
	'cfg_client_height' => 'Höhe',
	'cfg_client_height_explication' => 'Maximale Höhe des Bildes (px)',
	'cfg_client_quality' => 'Qualität',
	'cfg_client_quality_explication' => 'Komprimierung des Bildes nach dem Zuschneiden, Wert zwischen 0 und 100, Standard: 85',
	'cfg_client_width' => 'Breite',
	'cfg_client_width_explication' => 'Maximale Breite des Bildes (px)',
	'cfg_explication_parametrages' => 'Diese Optionen beziehen sich nur auf Dateifelder, die mit einem Drag-and-Drop-Block verwaltet werden.',
	'cfg_explication_retailler_image' => 'Wenn Breite und/oder Höhe angegeben sind, werden die Bilder vom Browser vor dem Senden an den Server in der Größe angepasst.',
	'cfg_max_file_size' => 'Maximale Dateigröße',
	'cfg_max_file_size_explication' => 'Maximale Dateigröße (in Mb).', # MODIF
	'cfg_titre_parametrages' => 'Datei-Upload',
	'cfg_titre_retailler_image' => 'Aktivieren Sie die Änderung der Bildgröße durch den Browser',
	'cfg_titre_retailler_image_actif' => 'Die Ändern der Bildgröße durch den Browser ist mit den folgenden Werten aktiviert',
	'choisir' => 'Auswählen',

	// D
	'deposer_la_vignette_ici' => 'Miniaturbild  hier ablegen',
	'deposer_le_logo_ici' => 'LOGO hier ablegen',
	'deposer_vos_fichiers_ici' => 'Dateien  hier ablegen',
	'deposer_votre_fichier_ici' => 'Datei hier ablegen',

	// E
	'erreur_de_transfert' => 'Übertragungsfehler',
	'erreur_probleme_survenu' => 'Ein Problem ist aufgetreten...',
	'erreur_taille_max' => 'Die Datei darf nicht größer sein als @taille@',
	'erreur_type_fichier' => 'Falscher Dateityp!',

	// F
	'fichier_efface' => 'Datei gelöscht',

	// O
	'ou' => 'oder',

	// S
	'selectionner' => 'Auswählen',
	'succes_fichier_envoye' => 'Die Datei wurde gesendet',
	'succes_logo_envoye' => 'Das Logo wurde gesendet',
	'succes_vignette_envoyee' => 'Das Miniaturbild wurde gesendet',

	// T
	'televerser' => 'Hochladen',
	'titre_page_configurer_bigup' => 'Big Upload konfigurieren',

	// Z
	'zbug_necessite_plugin' => 'Der Tag <code>@balise@</code> benötigt das Plugin <code>@plugin@</code>',
];
